# standard imports
import platform
import subprocess
import sys

# third-party imprts
import distro
from eyantra_autoeval.utils.common import is_docker, run_shell_command
from rich import print


def evaluate():
    result = {}

    distribution = {
        "machine": platform.machine(),
        "release": platform.release(),
        "system": platform.system(),
        "version": distro.version(best=True),
        "name": distro.name(),
    }
    result["distro"] = distribution

    result["virtualized"] = "hypervisor" in run_shell_command("cat /proc/cpuinfo")

    result["dockerized"] = is_docker()

    result["apt"] = {}
    result["apt"]["packages"] = {}
    packages = (
        subprocess.run(
            "apt list --installed | awk '{print $1 $2}' | awk -F'\/now' '{print $1 \" \" $2}'",
            capture_output=True,
            shell=True,
        )
        .stdout.decode()
        .split("\n")
    )
    packages = packages[1:-1]
    packages = [p.split() for p in packages]
    result["apt"]["packages"]["installed"] = packages

    packages = run_shell_command("pip3 freeze").split("\n")
    packages = [p.split("==") for p in packages]

    result["pip3"] = {}
    result["pip3"]["packages"] = {}
    result["pip3"]["packages"]["installed"] = packages

    result["ros"] = {}
    result["ros"]["version"] = run_shell_command("rosversion -d")
    result["ros"]["packages"] = {}
    packages = run_shell_command("rosversion -a").split("\n")
    packages = [p.split(": ") for p in packages]
    result["ros"]["packages"]["installed"] = run_shell_command("rosversion -a").split(
        "\n"
    )

    result["gazebo"] = {}
    result["gazebo"]["version"] = subprocess.run(
        "gazebo --version | grep 'Gazebo' | awk '{print $NF}'",
        capture_output=True,
        shell=True,
    ).stdout.decode()

    result["python"] = {}
    result["python"]["version"] = {}
    result["python"]["version"]["major"] = sys.version_info.major
    result["python"]["version"]["minor"] = sys.version_info.minor
    result["python"]["version"]["micro"] = sys.version_info.micro

    result["gdal"] = {}
    result["gdal"]["version"] = run_shell_command("gdalinfo --version")

    print(result)



# standard imports
import importlib

# third-party imprts
import click
from rich import print


@click.group()
def cli():
    pass


@click.command()
@click.option("--year", required=True, help="Year.")
@click.option("--theme", required=True, help="Theme Initials.")
@click.option("--task", required=True, help="Task Number.")
def evaluate(year, theme, task):
    """Dry run evaluation for a task."""
    print(
        f"Running evaluation scripts for [bold blue]{year}[/bold blue] "
        f"theme [bold blue]{theme}[/bold blue] for "
        f"task [bold blue]{task}[/bold blue]"
    )
    evaluator = importlib.import_module(
        f"eyantra_autoeval.year.y{year}.{theme}.task{task}.evaluator"
    )
    evaluator.evaluate()


cli.add_command(evaluate)




# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['eyantra_autoeval',
 'eyantra_autoeval.utils',
 'eyantra_autoeval.year.y2022.SD.task0']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.1.3,<9.0.0',
 'distro>=1.7.0,<2.0.0',
 'python-keycloak>=2.5.0,<3.0.0',
 'rich>=12.5.1,<13.0.0']

entry_points = \
{'console_scripts': ['eyantra-autoeval = eyantra_autoeval.console:cli']}

setup_kwargs = {
    'name': 'eyantra-autoeval',
    'version': '0.1.2',
    'description': 'A python module to aid auto evaluation',
    'long_description': '\n\n# e-Yantra Autoeval\n\n## Usage\n\n- For `Sentinel Drone` theme\n\n```sh\neyantra-autoeval evaluate --year 2022 --theme SD --task 0\n```\n\n',
    'author': 'Ameya Shenoy',
    'author_email': 'shenoy.ameya@gmail.com',
    'maintainer': 'Ameya Shenoy',
    'maintainer_email': 'shenoy.ameya@gmail.com',
    'url': 'https://github.com/erts-rnd/eyantra-autoeval',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



# standard imports
import os
import shlex
import subprocess


def is_docker():
    path = "/proc/self/cgroup"
    return (
        os.path.exists("/.dockerenv")
        or os.path.isfile(path)
        and any("docker" in line for line in open(path))
    )


def run_shell_command(command):
    try:
        return (
            subprocess.check_output(shlex.split(command)).decode().strip()
        )  # nosec B603
    except Exception as err:
        print(err)
        return ""
